Module query_types

Module query_types 

Structs

DesmosQueryWrapper
DesmosQueryWrapper is an override of QueryRequest::Custom to access desmos-specific modules
PostsResponse
PostsResponse contains a list of posts
ReactionsResponse
ReactionsResponse contains the list of reactions associated to the given post_id
ReportsResponse
ReportsResponse contains the list of reports associated with the given post_id

Enums

DesmosQuery
DesmosQuery represents the available desmos network queries