pub struct ReactionsResponse {
pub reactions: Vec<Reaction>,
}Expand description
ReactionsResponse contains the list of reactions associated to the given post_id
Fields
reactions: Vec<Reaction>Trait Implementations
Sourceimpl Clone for ReactionsResponse
impl Clone for ReactionsResponse
Sourcefn clone(&self) -> ReactionsResponse
fn clone(&self) -> ReactionsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReactionsResponse
impl Debug for ReactionsResponse
Sourceimpl<'de> Deserialize<'de> for ReactionsResponse
impl<'de> Deserialize<'de> for ReactionsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReactionsResponse
impl JsonSchema for ReactionsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReactionsResponse
impl PartialEq for ReactionsResponse
Sourceimpl Serialize for ReactionsResponse
impl Serialize for ReactionsResponse
impl StructuralPartialEq for ReactionsResponse