pub struct ReportsResponse {
pub reports: Vec<Report>,
}Expand description
ReportsResponse contains the list of reports associated with the given post_id
Fields
reports: Vec<Report>Trait Implementations
Sourceimpl Clone for ReportsResponse
impl Clone for ReportsResponse
Sourcefn clone(&self) -> ReportsResponse
fn clone(&self) -> ReportsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReportsResponse
impl Debug for ReportsResponse
Sourceimpl<'de> Deserialize<'de> for ReportsResponse
impl<'de> Deserialize<'de> for ReportsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReportsResponse
impl JsonSchema for ReportsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReportsResponse
impl PartialEq for ReportsResponse
Sourceimpl Serialize for ReportsResponse
impl Serialize for ReportsResponse
impl StructuralPartialEq for ReportsResponse