Structs
- Desmos
Query Wrapper - DesmosQueryWrapper is an override of QueryRequest::Custom to access desmos-specific modules
- Posts
Response - PostsResponse contains a list of posts
- Reactions
Response - ReactionsResponse contains the list of reactions associated to the given post_id
- Reports
Response - ReportsResponse contains the list of reports associated with the given post_id
Enums
- Desmos
Query - DesmosQuery represents the available desmos network queries